@@ -6,6 +6,7 @@ import tornado.options
 
 from .engine import Engine as dpEngine
 
+allowed_m17n = tornado.options.options.m17n
 session_default_expire_in = tornado.options.options.session_exp_in or 7200
 py_version = sys.version_info[0]
 
@@ -110,18 +111,28 @@ class Controller(dpEngine):
 
         return url
 
-    def redirect(self, url, prefix=False, permanent=False, status=None):
+    def redirect(self, url, prefix=False, permanent=False, status=None, safe=False):
         if self.parent._headers_written:
             return
 
         if prefix:
             url = self._prefix(url)
 
+        if safe and url and not url.startswith('/'):
+            url = '/'
+
         try:
             self.parent.redirect(url, permanent, status)
         except (AttributeError, TypeError):
             pass
 
+    def request_uri(self, s=False, d=' ', p='_', e=False, q=True):
+        r = ('%s%s' % (d, p)).join(self.request.uri.split('/')).strip() if s else self.request.uri
+        r = self._prefix(r)
+        r = r if q else r.split('?')[0:1][0]
+
+        return self.helper.url.quote(r) if e else r
+
     def render(self, template_name, kwargs=None):
         self._render = {'t': template_name, 'k': kwargs}
 
@@ -136,3 +147,10 @@ class Controller(dpEngine):
 
     def finish(self, chunk=None):
         self._finish = chunk
+
+    def m17n_lang(self, lang=None):
+        if lang is None:
+            m17n = self.parent.get_cookie('__m17n__')
+            return m17n if m17n in allowed_m17n else allowed_m17n[0]
+
+        return self.parent.m17n_lang(lang)
