@@ -34,6 +34,13 @@ class EngineSingleton(dpSingleton):
 
         return self._config
 
+    @property
+    def schema(self):
+        if not hasattr(self, '_schema'):
+            self._schema = dpLoader('schema')
+
+        return self._schema
+
     @property
     def model(self):
         if not hasattr(self, '_model'):
@@ -56,6 +63,14 @@ class EngineSingleton(dpSingleton):
 
         return self._view
 
+    @property
+    def m17n(self):
+        if not hasattr(self, '_m17n'):
+            from .m17n import M17n as dpM17n
+            self._m17n = dpM17n()
+
+        return self._m17n
+
     @property
     def cache(self):
         if not hasattr(self, '_cache'):
@@ -106,6 +121,10 @@ class Engine(object):
     def config(self):
         return EngineSingleton().config
 
+    @property
+    def schema(self):
+        return EngineSingleton().schema
+
     @property
     def model(self):
         return EngineSingleton().model
@@ -118,6 +137,10 @@ class Engine(object):
     def view(self):
         return EngineSingleton().view
 
+    @property
+    def m17n(self):
+        return EngineSingleton().m17n
+
     @property
     def cache(self):
         return EngineSingleton().cache
