@@ -35,6 +35,11 @@ class ConcurrentDecorator(object):
         return self.decorator(func)
 
 
+class InterruptException(Exception):
+    def __init__(self, handler):
+        self.handler = handler
+
+
 class Handler(tornado.web.RequestHandler, dpEngine):
     def __init__(self, application, request, **kwargs):
         super(Handler, self).__init__(application, request, **kwargs)
@@ -67,7 +72,10 @@ class Handler(tornado.web.RequestHandler, dpEngine):
 
     @ConcurrentDecorator(tornado.concurrent.run_on_executor)
     def route(self, method, path, initialize=None):
-        return self._route(method, path, initialize)
+        try:
+            return self._route(method, path, initialize)
+        except InterruptException as e:
+            return e.handler
 
     def _route(self, method, path, initialize=None):
         if self.interrupted:
@@ -152,7 +160,7 @@ class Handler(tornado.web.RequestHandler, dpEngine):
                         self.logging.error(e)
                         self.finish_with_error(500, 'An error has occurred')
 
-                return handler
+                raise InterruptException(handler)
 
             elif on_prepare is not True and paths_req:
                 paths_req.pop()
@@ -294,7 +302,13 @@ class Handler(tornado.web.RequestHandler, dpEngine):
         else:
             x = self.route(method, path)
 
-        self.postprocess(x)
+        try:
+            self.postprocess(x)
+
+        except Exception as e:
+            self.logger.exception(e)
+
+            raise e
 
     def __render(self, x):
         if not x._render:
@@ -416,6 +430,16 @@ class Handler(tornado.web.RequestHandler, dpEngine):
         except (AttributeError, TypeError):
             pass
 
+    def _prefix(self, url):
+        if 'X-Proxy-Prefix' in self.request.headers:
+            prefix = self.request.headers['X-Proxy-Prefix']
+            prefix = prefix[:-1] if prefix.endswith('/') else prefix
+
+            if url.startswith(prefix):
+                url = url[len(prefix):] or '/'
+
+        return url
+
     def get_user_agent(self, parsed=True):
         if not parsed:
             return self.request.headers['User-Agent'] if 'User-Agent' in self.request.headers else ''
@@ -478,3 +502,14 @@ class Handler(tornado.web.RequestHandler, dpEngine):
 
     def on_interrupt(self):
         pass
+
+    def m17n_lang(self, lang=None):
+        if lang is None:
+            import tornado.options
+
+            allowed_m17n = tornado.options.options.m17n
+            m17n = self.get_cookie('__m17n__')
+
+            return m17n if m17n in allowed_m17n else allowed_m17n[0]
+
+        self.m17n.set(self, lang)
