@@ -45,6 +45,7 @@ def weekday(c, t):
 
 def request_uri(c, s=False, d=' ', p='_', e=False, q=True):
     r = ('%s%s' % (d, p)).join(c.request.uri.split('/')).strip() if s else c.request.uri
+    r = prefix(c, r)
     r = r if q else r.split('?')[0:1][0]
     return c.helper.url.quote(r) if e else r
 
@@ -53,6 +54,13 @@ def i18n(c):
     return c.helper.i18n
 
 
+def m17n(c, m17n_lang=None):
+    if not m17n_lang:
+        m17n_lang = c.get_cookie('__m17n__')
+
+    return c.m17n.get(m17n_lang)
+
+
 def c(c):
     return c
 
@@ -94,7 +102,7 @@ def prefix(c, static_url, query=None, combine_request_query=False, prefix=None,
         p = p[:-1] if p.endswith('/') else p
 
         if static_url.startswith(p):
-            return static_url[len(p):]
+            return static_url[len(p):] or '/'
 
         return static_url
     else:
